﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 포인트 시리즈
        /// </summary>
        private Points points;

        /// <summary>
        /// 상관 관계 함수
        /// </summary>
        private CorrelationFunction correlationFunction;

        /// <summary>
        /// 라인 1 시리즈
        /// </summary>
        private Line line1;

        /// <summary>
        /// 트렌드 함수
        /// </summary>
        private TrendFunction trendFunction;

        /// <summary>
        /// 라인 2 시리즈
        /// </summary>
        private Line line2;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 포인트 시리즈를 생성한다.

            this.points = new Points();

            this.points.Title         = "Data";
            this.points.Color         = Color.FromArgb(130, 155, 254);
            this.points.Pointer.Style = PointerStyles.Diamond;

            #endregion
            #region 상관 관계 함수를 생성한다.

            this.correlationFunction = new CorrelationFunction();

            #endregion
            #region 라인 1 시리즈를 생성한다.

            this.line1 = new Line();

            this.line1.Title               = "Correlation";
            this.line1.Brush.Color         = Color.FromArgb(252, 209, 36 );
            this.line1.Color               = Color.FromArgb(252, 209, 36 );
            this.line1.Pointer.Brush.Color = Color.FromArgb(255, 255, 255);
            this.line1.VertAxis            = VerticalAxis.Right;
            this.line1.DataSource          = this.points;
            this.line1.Function            = this.correlationFunction;

            #endregion
            #region 트렌드 함수를 생성한다.

            this.trendFunction = new TrendFunction();

            #endregion
            #region 라인 2 시리즈를 생성한다.

            this.line2 = new Line();

            this.line2.Title               = "Trend";
            this.line2.Brush.Color         = Color.FromArgb(124, 188, 13 );
            this.line2.Color               = Color.FromArgb(124, 188, 13 );
            this.line2.Pointer.Brush.Color = Color.FromArgb(255, 255, 255);
            this.line2.DataSource          = this.points;
            this.line2.Function            = this.trendFunction;
            this.line2.Visible             = false;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Axes.Left.MaximumOffset   = 5;
            this.tChart.Axes.Left.MinimumOffset   = 5;
            this.tChart.Axes.Bottom.MaximumOffset = 5;
            this.tChart.Axes.Bottom.MinimumOffset = 5;

            this.tChart.Series.Add(this.points);
            this.tChart.Series.Add(this.line1);
            this.tChart.Series.Add(this.line2);

            #endregion

            this.points.FillSampleValues(20);

            this.showTrendCheckBox.CheckedChanged += showTrendCheckBox_CheckedChanged;
            this.refreshButton.Click              += refreshButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 트렌트 표시 체크 박스 체크 변경시 처리하기 - showTrendCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 트렌트 표시 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showTrendCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.line2.Active = this.showTrendCheckBox.Checked;
        }

        #endregion
        #region 갱신하기 버튼 클릭시 처리하기 - refreshButton_Click(sender, e)

        /// <summary>
        /// 갱신하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void refreshButton_Click(object sender, EventArgs e)
        {
            this.points.FillSampleValues(20);
        }

        #endregion
    }
}